<!--勤务排班-->
<template>
  <div>
    <!--  头部  -->
    <van-sticky>
      <van-nav-bar
        title="勤务排班"
        left-arrow
        @click-left="_ => $router.go(-1)"
      />
    </van-sticky>

    <van-row>
      <van-col span="24">
        <van-dropdown-menu>
          <van-dropdown-item v-model="value1" :options="option1" @change="orgChange" />
          <van-dropdown-item v-model="value2" :options="option2" @change="monthChange" />
        </van-dropdown-menu>
      </van-col>
      <!--      <van-col span="6">-->
      <!--        <van-button style="width:100%" :loading="loading" type="primary" @click="fastWorkArrange">一键排班</van-button>-->
      <!--      </van-col>-->
    </van-row>

    <van-calendar
      :title="caltitle"
      :default-date="defaultDate"
      :min-date="minDate"
      :max-date="maxDate"
      :poppable="false"
      :show-confirm="false"
      :show-title="false"
      :show-subtitle="false"
      :row-height="100"
    >
      <div slot="bottom-info" slot-scope="day">
        <van-tag v-for="item in getDayArranging(day)" :key="item.id" size="medium" round :color="item.color"
                 @click="onSelect(item)">{{ item.className }}
        </van-tag>
      </div>
      <div slot="top-info" slot-scope="day">
        <van-tag v-if="getDayArranging(day).length>0" plain type="success">在岗</van-tag>
        <van-tag v-else plain type="warning">未排班</van-tag>
      </div>
    </van-calendar>
  </div>
</template>

<script>

import CommonApi from '@/views/Manage/CommonApi.js'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import {Dialog, Toast} from 'vant'

import CmgtDutyWorkarrangeApi from '@/views/Manage/duty/api/CmgtDutyWorkarrangeApi'

export default {
  name: 'MobileDutyWorkArranged', // 勤务排班
  data() {
    return {
      dutyArrangeList: [],
      caltitle: '',
      defaultDate: new Date(2010, 5, 1),
      minDate: new Date(2010, 5, 1),
      maxDate: new Date(2010, 12, 1),
      value1: 0,
      value2: '0',
      option1: [
        {text: '综合局部门', value: 0}
      ],
      option2: [
        {text: '月份', value: 'a'}
      ],
      currentUser: {},
      params: {
        trainingDate: ''
      },
      showPicker: false,
      loading: false,
      finished: true,
      refreshing: false
    }
  },
  mounted() {
    // 保证两个下拉框的配置数组都成功获取到后，再请求排班信息
    const {loadZGJOrgs, loadDutyMonths} = CommonApi
    Promise.all([loadZGJOrgs(), loadDutyMonths()]).then(([option1, option2]) => {
      this.option1 = option1
      this.option2 = option2
      this.value1 = option1[0].value
      this.value2 = option2.length - 2
      this.queryDutyArrange()
    })

    this.currentUser = JSON.parse(sessionStorage.getItem('currentUser'))
    this.deviceStatus = dictUtils.getDictItemsFromCache('sbzt')
  },

  methods: {
    onSelect(item) {
      const cdate = '【' + item.arrangeDate + '】' + item.className + '(' + item.startDate + ' - ' + item.endDate + ')'
      var v = ''
      item.members.forEach(m => {
        v = v + m.name + (m.phone ? '(' + m.phone + ')' : '') + '\n'
      })
      Dialog.alert({
        title: cdate,
        message: v
      }).then(() => {
        // on close
      })
    },
    queryDutyArrange() {
      CmgtDutyWorkarrangeApi.findMonthArrangeInfo({
        date: this.option2[this.value2].min,
        orgId: this.value1
      }, res => {
        this.dutyArrangeList = res.value
        // this.caltitle = this.value1
        this.minDate = new Date(this.option2[this.value2].min)
        this.maxDate = new Date(this.option2[this.value2].max)
        this.defaultDate = this.minDate
      })
    },
    monthChange(v) {
      this.queryDutyArrange()
    },
    orgChange(v) {
      this.queryDutyArrange()
    },

    getDayArranging(day) {
      if (day.type === 'placeholder') {
        return []
      }
      const cdate = day.date.format('yyyy-MM-dd')
      // console.log('=========r.arrangeDate === cdate)=========', this.dutyArrangeList.filter(r => r.arrangeDate === cdate))
      return this.dutyArrangeList.filter(r => r.arrangeDate === cdate)
    },
    formatter(day) {
      day.topInfo = day.text
      const cdate = day.date.format('yyyy-MM-dd')
      day.text = null
      day.bottomInfo = ''

      this.dutyArrangeList.forEach(d => {
        if (cdate === d.arrangeDate) {
          if (d.team) {
            day.bottomInfo = day.bottomInfo + d.team + '\n'
          } else {
            day.bottomInfo = day.bottomInfo + d.className + '\n'
          }
        }
      })
      // day.text = 'xxxxx,\r\n sdfasdf\r\n sdfasdf\r\n sdfasdf\r\n sdfasdf\r\n sdfasdf'
      return day
    },
    fastWorkArrange() {
      if (this.value2 == null || this.value2 === '') {
        Toast.fail('请选择排班时间！')

        return
      }
      const orgId = this.value1
      const searchDate = this.option2[this.value2].wd
      if (orgId == null || orgId === '') {
        Toast.fail('请选择部门信息！')
        return
      }
      var orgName = this.option1.find(e => e.value === orgId).text
      Dialog.confirm({
        title: '提示',
        message: '一键排班【' + orgName + searchDate + '排班】, 是否继续?'
      })
        .then(() => {
          this.loading = true
          CmgtDutyWorkarrangeApi.fastWorkArrange({
            date: searchDate,
            orgId: orgId
          }, res => {
            this.queryDutyArrange()
            this.loading = false
          })
        }).catch(() => {
        this.loading = false
      })
    }
  }
}
</script>

<style lang="scss" scoped>
@import "@/assets/css/vant-custom";
@import "@/assets/css/element-variables";

::v-deep .van-ellipsis {
  font-size: 14PX;
}

</style>
